:root {
    --background-color: #d9d9d9;
    --form-background: #f2f2f2;
    --form-text: #777777;
    --form-edit: #777777;
    --hr-color: #eee;
    --border-color: #cccccc;
    --text-color: #f2f2f2;
    --opacity: 1;
    --footer-color: brown;
    --dot-for-link: blue;
}

body {
    background: var(--background-color);
    padding: 0px;
    margin: 0px;

}

.wrapper{
    background: url(body-background.png)
}

.btn-primary, .btn-primary:hover, .btn-primary:active,
.btn-danger, .btn-danger:hover, .btn-danger:active {
    color:  var(--text-color) !important;
}

.badge-warning, .badge-warning:hover, .badge-warning:active, .badge-warning:visited {
    background-color: var(--form-edit) !important;
    color: var(--text-color); !important;
}
.progress{
    margin:10px;
    background-color: var(--background-color);
    opacity: var(--opacity); 
    }

.station-display input:placeholder-shown {
    background-color:  var(--form-background) !important;
    border: 1px;
    border-style: solid !important;
    border-color:  var(--border-color) !important;
}

.station-display input:not(:placeholder-shown) {
    background-color:  var(--form-background) !important;
    border: 2px;
    border-style: solid !important;
    border-color:   #4195fc !important;
    border-radius: 5px;
    box-shadow: 0px 0px 4px #4195fc;
    color:  var(--form-text) !important;
}

.dot-for-link {
color: var(--dot-for-link); !important;
}

#time_record_select_all {
    background: var(--form-background);
    color: #666666;
    border-color: var(--border-color);
}
#body_color_select_all{
    background: var(--form-background);
    color: #666666;
    border-color: var(--border-color);
}
hr {
    border-top: 1px solid var(--hr-color);
}
h1 {
    border: 2px var(--border-color) solid;
    color: brown;
    text-align: center;
    padding: 10px;

}

.pixies { 
    background-color: var(--background-color);
}
.pixies img { 
    opacity: var(--opacity); 
}

.navbar{ 
    
    background: var(--background-color);
}
.navbar-brand {
    background: var(--background-color);
}


/* navbar */
.navbar-toggle {
  float: left !important;
  margin-left: 15px;
  background: var(--background-color);
}

.navbar-header.navbar-right.pull-right {
  margin-right: 15px;
  background: var(--background-color);
}

.navbar-right > li {
  float: left;
  background: var(--background-color);
}

.visually-hidden {
  clip: rect(0 0 0 0);
  clip-path: inset(50%);
  height: 1px;
  overflow: hidden;
  position: absolute;
  white-space: nowrap;
  width: 1px;
}

[hidden] {
  display: none !important;
}


body, html, .wrap{
  height:100%;
}

body > .wrap{
  height:auto;
  min-height:100%;
}

.wrap:after {
  content: "";
  display: block;
  height: 75px; 
}

.footer{
  background-color: var(--footer-color);
  margin-top:-75px;
  height:70px;
  position:relative;
  line-height:180%;
  padding:0 2px;
}

.middle > * {
  vertical-align: middle;
}

.top > * {
  vertical-align: top;
}

.bottom > * {
  vertical-align: bottom;
}

.sub > * {
  vertical-align: sub;
}

.super > * {
  vertical-align: super;
}

.text-top > * {
  vertical-align: text-top;
}

.text-bottom > * {
  vertical-align: text-bottom;
}

.baseline > * {
  vertical-align: baseline;
}

.pix > * {
  vertical-align: 3px;
}

.percentage > * {
  vertical-align: -500%;
}



